cgexplore.terms.TargetTorsion
=============================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetTorsion
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetTorsion.human_readable
      ~TargetTorsion.vector
      ~TargetTorsion.vector_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetTorsion.search_string
      ~TargetTorsion.search_estring
      ~TargetTorsion.measured_atom_ids
      ~TargetTorsion.phi0
      ~TargetTorsion.torsion_k
      ~TargetTorsion.torsion_n
      ~TargetTorsion.funct
   
   